@@ -15,7 +15,7 @@ class Cosmo(object):
         :param d_s: angular diameter distance to the source
         :param d_ds: angular diameter distance between deflector and source
         """
-        if d_ds <= 0 or d_s <= 0 or d_d <=0:
+        if d_ds <= 0 or d_s <= 0 or d_d <= 0:
             raise ValueError('input angular diameter distances Dd: %s, Ds: %s, Dds: %s are not suppored for a lens'
                              ' model!' % (d_d, d_s, d_ds))
         self.dd = float(d_d)  # angular diameter distance from observer to deflector in physical Mpc
@@ -35,8 +35,8 @@ class Cosmo(object):
         """
         returns the critical projected mass density in units of M_sun/Mpc^2 (physical units)
         """
-        const_SI = const.c**2 / (4*np.pi * const.G)  # c^2/(4*pi*G) in units of [kg/m]
+        const_si = const.c**2 / (4*np.pi * const.G)  # c^2/(4*pi*G) in units of [kg/m]
         conversion = const.Mpc / const.M_sun  # converts [kg/m] to [M_sun/Mpc]
-        pre_const = const_SI * conversion  # c^2/(4*pi*G) in units of [M_sun/Mpc]
-        Epsilon_Crit = self.ds / (self.dd * self.dds) * pre_const  # [M_sun/Mpc^2]
-        return Epsilon_Crit
+        pre_const = const_si * conversion  # c^2/(4*pi*G) in units of [M_sun/Mpc]
+        epsilon_crit = self.ds / (self.dd * self.dds) * pre_const  # [M_sun/Mpc^2]
+        return epsilon_crit
