@@ -118,8 +118,6 @@ class LensEquationSolver(object):
         :param magnification_limit: None or float, if set will only return image positions that have an
          abs(magnification) larger than this number
         :param kwargs_solver: additional kwargs to be supplied to the solver. Particularly relevant are Nmeas and Nmeas_extra
-        :param Nmeas: resolution with which to sample the angular grid, higher means more reliable lens equation solving. For solving many positions at once, you may want to set this higher.
-        :param Nmeas_extra: resolution with which to additionally sample the angular grid at the low-shear end, higher means more reliable lens equation solving. For solving many positions at once, you may want to set this higher.
         :returns: (exact) angular position of (multiple) images ra_pos, dec_pos in units of angle
          Note: in contrast to the other solvers, generally the (heavily demagnified) central image will also be included, so
          setting a a proper magnification_limit is more important. To get similar behaviour, a limit of 1e-1 is acceptable
@@ -206,7 +204,7 @@ class LensEquationSolver(object):
         y_mins = np.append(y_mins, np.random.uniform(low=-search_window / 2 + y_center,
                                                      high=search_window / 2 + y_center, size=num_random))
         # iterative solving of the lens equation for the selected grid points
-        #print("Candidates:", x_mins.shape, y_mins.shape)
+        # print("Candidates:", x_mins.shape, y_mins.shape)
         x_mins, y_mins, solver_precision = self._find_gradient_decent(x_mins, y_mins, sourcePos_x, sourcePos_y, kwargs_lens,
                                                                       precision_limit, num_iter_max, verbose=verbose,
                                                                       min_distance=min_distance, non_linear=non_linear)
