@@ -1,7 +1,6 @@
 __author__ = 'herjy', 'aymgal'
 
 import numpy as np
-import scipy.signal as scs
 import scipy.ndimage.filters as scf
 
 from lenstronomy.Util.package_util import exporter
@@ -30,37 +29,35 @@ def transform(img, n_scales, second_gen=False):
     n = np.size(h)
     h = np.array(h)
     
-    max_lvl = np.min( (lvl, int(np.log2(n2))) )
+    max_lvl = np.min((lvl, int(np.log2(n2))))
     if lvl > max_lvl:
         raise ValueError("Maximum decomposition level is {} (required: {})".format(max_lvl, lvl))
     elif lvl <= 0:
         raise ValueError("Number of decomposition level can not be non-positive")
 
     c = img
-    ## wavelet set of coefficients.
+    # wavelet set of coefficients.
     wave = np.zeros((lvl+1, n1, n2))
 
     for i in range(lvl):
         newh = np.zeros((1, n+(n-1)*(2**i-1)))
         newh[0, np.linspace(0, np.size(newh)-1, len(h), dtype=int)] = h
 
-        H = np.dot(newh.T, newh)
+        # H = np.dot(newh.T, newh)
 
         ######Calculates c(j+1)
         ###### Line convolution
         cnew = scf.convolve1d(c, newh[0, :], axis=0, mode=mode)
 
         ###### Column convolution
-        cnew = scf.convolve1d(cnew, newh[0,:],axis=1, mode=mode)
+        cnew = scf.convolve1d(cnew, newh[0, :], axis=1, mode=mode)
 
- 
-      
         if second_gen:
             ###### hoh for g; Column convolution
-            hc = scf.convolve1d(cnew, newh[0, :],axis=0, mode=mode)
+            hc = scf.convolve1d(cnew, newh[0, :], axis=0, mode=mode)
 
             ###### hoh for g; Line convolution
-            hc = scf.convolve1d(hc, newh[0, :],axis=1, mode=mode)
+            hc = scf.convolve1d(hc, newh[0, :], axis=1, mode=mode)
             
             ###### wj+1 = cj - hcj+1
             wave[i, :, :] = c - hc
@@ -69,7 +66,6 @@ def transform(img, n_scales, second_gen=False):
             ###### wj+1 = cj - cj+1
             wave[i, :, :] = c - cnew
 
-
         c = cnew
      
     wave[i+1, :, :] = c
@@ -97,7 +93,6 @@ def inverse_transform(wave, fast=True, second_gen=False):
     n = np.size(h)
 
     cJ = np.copy(wave[lvl-1, :, :])
-    
 
     for i in range(1, lvl):
         
