@@ -11,7 +11,7 @@ class ImageLikelihood(object):
 
     def __init__(self, multi_band_list, multi_band_type, kwargs_model, bands_compute=None,
                  image_likelihood_mask_list=None, source_marg=False, linear_prior=None, check_positive_flux=False,
-                 kwargs_pixelbased=None):
+                 kwargs_pixelbased=None, linear_solver=True):
         """
 
         :param bands_compute: list of bools with same length as data objects, indicates which "band" to include in the
@@ -26,11 +26,13 @@ class ImageLikelihood(object):
          parameters
         :param kwargs_pixelbased: keyword arguments with various settings related to the pixel-based solver
          (see SLITronomy documentation)
+        :param linear_solver: bool, if True (default) fixes the linear amplitude parameters 'amp' (avoid sampling) such
+         that they get overwritten by the linear solver solution.
         """
         self.imSim = class_creator.create_im_sim(multi_band_list, multi_band_type, kwargs_model,
                                                  bands_compute=bands_compute,
-                                                 likelihood_mask_list=image_likelihood_mask_list,
-                                                 kwargs_pixelbased=kwargs_pixelbased)
+                                                 image_likelihood_mask_list=image_likelihood_mask_list,
+                                                 kwargs_pixelbased=kwargs_pixelbased, linear_solver=linear_solver)
         self._model_type = self.imSim.type
         self._source_marg = source_marg
         self._linear_prior = linear_prior
@@ -77,7 +79,6 @@ class ImageLikelihood(object):
         """
 
         :param cache: boolean
-        :return:
+        :return: None
         """
         self.imSim.reset_point_source_cache(cache=cache)
-
