@@ -67,7 +67,7 @@ class UpdateManager(object):
 
         self._kwargs_temp = self.init_kwargs
 
-    # TODO: check compatibility with number of point sources provided as well as other parameter labelings
+    # TODO: check compatibility with number of point sources provided as well as other parameter labeling
 
     @property
     def init_kwargs(self):
@@ -156,7 +156,7 @@ class UpdateManager(object):
                              'kwargs_lens_light': kwargs_lens_light, 'kwargs_ps': kwargs_ps,
                              'kwargs_special': kwargs_special, 'kwargs_extinction': kwargs_extinction}
 
-    def update_param_value(self, lens=[], source=[], lens_light=[], ps=[]):
+    def update_param_value(self, lens=None, source=None, lens_light=None, ps=None):
         """
         Set a model parameter to a specific value.
 
@@ -166,6 +166,14 @@ class UpdateManager(object):
         :param ps: [[i_model, ['param1', 'param2',...], [...]]
         :return: 0, the value of the param is overwritten
         """
+        if lens is None:
+            lens = []
+        if source is None:
+            source = []
+        if lens_light is None:
+            lens_light = []
+        if ps is None:
+            ps = []
         for items, kwargs_key in zip([lens, source, lens_light, ps],
             ['kwargs_lens', 'kwargs_source', 'kwargs_lens_light', 'kwargs_ps']):
             for item in items:
@@ -200,7 +208,7 @@ class UpdateManager(object):
                             kwargs_lens_init=lens_temp, **kwargs_constraints)
         return param_class
 
-    def update_options(self, kwargs_model, kwargs_constraints, kwargs_likelihood):
+    def update_options(self, kwargs_model=None, kwargs_constraints=None, kwargs_likelihood=None):
         """
         updates the options by overwriting the kwargs with the new ones being added/changed
         WARNING: some updates may not be valid depending on the model options. Use carefully!
@@ -211,6 +219,12 @@ class UpdateManager(object):
         :param kwargs_likelihood:
         :return: kwargs_model, kwargs_constraints, kwargs_likelihood
         """
+        if kwargs_model is None:
+            kwargs_model = {}
+        if kwargs_constraints is None:
+            kwargs_constraints = {}
+        if kwargs_likelihood is None:
+            kwargs_likelihood = []
         kwargs_model_updated = self.kwargs_model.update(kwargs_model)
         kwargs_constraints_updated = self.kwargs_constraints.update(kwargs_constraints)
         kwargs_likelihood_updated = self.kwargs_likelihood.update(kwargs_likelihood)
@@ -227,13 +241,13 @@ class UpdateManager(object):
         :param change_lens_upper_limit: [[i_model, ['param_name', ...], [value1, value2, ...]]]
         :return: updates internal state of lower and upper limits accessible from outside
         """
-        if not change_source_lower_limit is None:
+        if change_source_lower_limit is not None:
             self._source_lower = self._update_limit(change_source_lower_limit, self._source_lower)
-        if not change_source_upper_limit is None:
+        if change_source_upper_limit is not None:
             self._source_upper = self._update_limit(change_source_upper_limit, self._source_upper)
-        if not change_lens_lower_limit is None:
+        if change_lens_lower_limit is not None:
             self._lens_lower = self._update_limit(change_lens_lower_limit, self._lens_lower)
-        if not change_lens_upper_limit is None:
+        if change_lens_upper_limit is not None:
             self._lens_upper = self._update_limit(change_lens_upper_limit, self._lens_upper)
 
     @staticmethod
@@ -253,9 +267,9 @@ class UpdateManager(object):
                 kwargs_limit_updated[i_model][param_name] = values[j]
         return kwargs_limit_updated
 
-    def update_fixed(self, lens_add_fixed=[], source_add_fixed=[], lens_light_add_fixed=[], ps_add_fixed=[],
-                     special_add_fixed=[], lens_remove_fixed=[], source_remove_fixed=[], lens_light_remove_fixed=[],
-                     ps_remove_fixed=[], special_remove_fixed=[]):
+    def update_fixed(self, lens_add_fixed=None, source_add_fixed=None, lens_light_add_fixed=None, ps_add_fixed=None,
+                     special_add_fixed=None, lens_remove_fixed=None, source_remove_fixed=None,
+                     lens_light_remove_fixed=None, ps_remove_fixed=None, special_remove_fixed=None):
         """
         adds or removes the values of the keyword arguments that are stated in the _add_fixed to the existing fixed
         arguments. convention for input arguments are:
@@ -283,11 +297,15 @@ class UpdateManager(object):
         ps_fixed = self._remove_fixed(ps_fixed, ps_remove_fixed)
         special_fixed = copy.deepcopy(self._special_fixed)
         special_temp = self._kwargs_temp['kwargs_special']
+        if special_add_fixed is None:
+            special_add_fixed = []
         for param_name in special_add_fixed:
             if param_name in special_fixed:
                 pass
             else:
                 special_fixed[param_name] = special_temp[param_name]
+        if special_remove_fixed is None:
+            special_remove_fixed = []
         for param_name in special_remove_fixed:
             if param_name in special_fixed:
                 del special_fixed[param_name]
@@ -299,10 +317,13 @@ class UpdateManager(object):
 
         :param kwargs_model: model parameters
         :param kwargs_fixed: parameters that are held fixed (even before)
-        :param add_fixed: additional fixed parameters [[i_model, ['param_name1', 'param_name2', ...], [value1, value2, ... (optional)], [], ...]
+        :param add_fixed: additional fixed parameters
+         [[i_model, ['param_name1', 'param_name2', ...], [value1, value2, ... (optional)], [], ...]
         :return: updated kwargs_fixed
         """
-        #fixed_kwargs = copy.deepcopy(kwargs_fixed)
+        if add_fixed is None:
+            add_fixed = []
+        # fixed_kwargs = copy.deepcopy(kwargs_fixed)
         for i in range(len(add_fixed)):
             i_model = add_fixed[i][0]
             fix_names = add_fixed[i][1]
@@ -326,6 +347,8 @@ class UpdateManager(object):
          kwargs_model [[i_model, ['param_name1', 'param_name2', ...]], [], ...]
         :return: updated kwargs fixed parameters
         """
+        if remove_fixed is None:
+            remove_fixed = []
         for i in range(len(remove_fixed)):
             i_model = remove_fixed[i][0]
             fix_names = remove_fixed[i][1]
