@@ -67,7 +67,7 @@ class TestLensCosmo(object):
         h = 0.7
 
         for z in zvals:
-            nfw_colossus = NFWProfile(m200 * h, z, mdef='200c')
+            nfw_colossus = NFWProfile(M=m200 * h, z=z, c=c, mdef='200c')
             rhos_colossus, rs_colossus = nfw_colossus.fundamentalParameters(m200 * h, c, z, mdef='200c')
             r200_colossus = rs_colossus * c
 
@@ -75,7 +75,6 @@ class TestLensCosmo(object):
             rs_colossus *= h ** -1
             rhos_colossus *= h ** 2
 
-
             r200_lenstronomy = nfw_param.r200_M(m200 * h, z) / h  # physical radius r200
             rs_lenstronomy = r200_lenstronomy / c
             rhos_lenstronomy = nfw_param.rho0_c(c, z) * h ** 2  # physical density in M_sun/Mpc**3
