@@ -67,6 +67,11 @@ class TestLightModel(object):
         param_name_list = self.LightModel.param_name_list
         assert len(self.light_model_list) == len(param_name_list)
 
+    def test_param_name_list_latex(self):
+        param_name_list = self.LightModel.param_name_list_latex
+        assert len(self.light_model_list) == len(param_name_list)
+
+
     def test_num_param_linear(self):
         num = self.LightModel.num_param_linear(self.kwargs, list_return=False)
         assert num == 19
